
Package radical.repex
========================

This package implements a somewhat generic replica exchange framework


License
-------

This software is released under the
[MIT License v3.0](http://opensource.org/licenses/MIT).


